@@ -1,7 +1,7 @@
 package Perinci::Sub::Normalize;
 
-our $DATE = '2015-09-30'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2015-12-23'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,12 +13,6 @@ our @EXPORT_OK = qw(
                        normalize_function_metadata
                );
 
-use Sah::Schema::Rinci;
-my $sch = $Sah::Schema::Rinci::SCHEMAS{rinci_function}
-    or die "BUG: Rinci schema structure changed (1)";
-my $sch_proplist = $sch->[1]{_prop}
-    or die "BUG: Rinci schema structure changed (2)";
-
 sub _normalize{
     my ($meta, $ver, $opts, $proplist, $nmeta, $prefix, $modprefix) = @_;
 
@@ -147,6 +141,12 @@ sub normalize_function_metadata($;$) {
     $opts->{normalize_sah_schemas}       //= 1;
     $opts->{remove_internal_properties}  //= 0;
 
+    require Sah::Schema::Rinci;
+    my $sch = $Sah::Schema::Rinci::SCHEMAS{rinci_function}
+        or die "BUG: Rinci schema structure changed (1)";
+    my $sch_proplist = $sch->[1]{_prop}
+        or die "BUG: Rinci schema structure changed (2)";
+
     _normalize($meta, 1.1, $opts, $sch_proplist, {}, '');
 }
 
@@ -165,7 +165,7 @@ Perinci::Sub::Normalize - Normalize Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.13 of Perinci::Sub::Normalize (from Perl distribution Perinci-Sub-Normalize), released on 2015-09-30.
+This document describes version 0.14 of Perinci::Sub::Normalize (from Perl distribution Perinci-Sub-Normalize), released on 2015-12-23.
 
 =head1 SYNOPSIS
 
